@@ -53,15 +53,17 @@ setMethod(
   signature=signature(object="kalmand_pomp"),
   definition=function (object, vars, ...,
     format = c("array", "data.frame")) {
-    if (missing(vars)) vars <- rownames(object@filter.mean)
-    format <- match.arg(format)
-    if (format == "array") {
-      object@filter.mean[vars,,drop=FALSE]
+    if (missing(vars)) {
+      x <- object@filter.mean
     } else {
+      x <- object@filter.mean[vars,,drop=FALSE]
+    }
+    format <- match.arg(format)
+    if (format == "data.frame") {
       x <- melt(object@filter.mean[vars,,drop=FALSE])
       x$time <- time(object)[as.integer(x$time)]
-      x
     }
+    x
   }
 )
 
@@ -72,14 +74,16 @@ setMethod(
   signature=signature(object="pfilterd_pomp"),
   definition=function (object, vars, ...,
     format = c("array", "data.frame")) {
-    if (missing(vars)) vars <- rownames(object@filter.mean)
-    format <- match.arg(format)
-    if (format == "array") {
-      object@filter.mean[vars,,drop=FALSE]
+    if (missing(vars)) {
+      x <- object@filter.mean
     } else {
+      x <- object@filter.mean[vars,,drop=FALSE]
+    }
+    format <- match.arg(format)
+    if (format == "data.frame") {
       x <- melt(object@filter.mean[vars,,drop=FALSE])
       x$time <- time(object)[as.integer(x$time)]
-      x
     }
+    x
   }
 )
